Customs Value Module
####################


This module was built to be a supporting module for the shipping modules
that integrates with carriers like FedEx, UPS and USPS. When
generating international shipment labels, the carriers expect customs
value to be electronically transferred to them.
 
Why not just use list price ?
-----------------------------
 
This works for most businesses. This is indeed the default behavior of
this module.

On the other hand, if you are wholesaler, you may not want
the retail list price being sent as the customs value for the product.

